@@ -7,7 +7,7 @@
 #include <QMaemo5ListPickSelector>
 #include "xml.h"
 
-class NewExerciseWindow : public QDialog
+class NewExerciseWindow : public QMainWindow
 {
     Q_OBJECT
 public:
