@@ -452,6 +452,39 @@ void XML::import(QString filename)
    }
 }
 
+void XML::exportExercises(QModelIndexList name)
+{
+    QList <QString> list;
+    QString group, muscle, info;
+    QModelIndex tmp;
+
+    QDomDocument doc( "Exercises" );
+    QDomElement root = doc.createElement( "exercises" );
+    doc.appendChild( root );
+
+    while(!name.isEmpty())
+    {
+        tmp = name.takeFirst();
+        list = openEx(tmp.data().toString());
+        list.removeFirst();
+        group = list.takeFirst();
+        muscle = list.takeFirst();
+        info = list.takeFirst();
+
+
+        root.appendChild(createExerciseNode(doc, tmp.data().toString(), group, muscle, info));
+    }
+    QFile file( "/home/user/MyDocs/export.xml" );
+
+    if(!file.open(QIODevice::WriteOnly))
+        return;
+    QTextStream ts( &file );
+    ts << doc.toString();
+
+   file.close();
+   return;
+}
+
 void XML::saveEx(QString name, QString group, QString muscle,
                     QString info)
 {
